@@ -5,11 +5,11 @@ $.fn.dataTable.ext.buttons.editRefresh = {
         var that = this;
         this.processing( true );
 
-        config.editor._event( 'preEditRefresh', [dt, config.editor.s.action] )
-
         // Get currently selected row ids
         var selectedRows = dt.rows({selected:true}).ids();
 
+        config.editor._event( 'preEditRefresh', [dt, config.editor.s.action, node, config, selectedRows] )
+
         // Ajax request to refresh the data for those ids
         $.ajax( {
             // application specific: my application has different urls for different methods
@@ -23,12 +23,14 @@ $.fn.dataTable.ext.buttons.editRefresh = {
                 ids: selectedRows.toArray().join(',')
             },
             success: function ( json ) {
-                // Update the rows we get data back for
-                for ( var i=0 ; i<json.data.length ; i++ ) {
-                    // shouldn't use DT_RowId because of rowId configuration possibility
-                    dt.row( '#'+json.data[i][dt.init().rowId] ).data( json.data[i] );
+                if (json.data) {
+                    // Update the rows we get data back for
+                    for (var i = 0; i < json.data.length; i++) {
+                        // shouldn't use DT_RowId because of rowId configuration possibility
+                        dt.row('#' + json.data[i][dt.init().rowId]).data(json.data[i]);
+                    }
+                    dt.draw(false);
                 }
-                dt.draw(false);
 
                 // Trigger the original edit button's action
                 $.fn.dataTable.ext.buttons.edit.action.call(that, e, dt, node, config);
